#ifndef __TEXT_H__
#define __TEXT_H__

#include "GapiDraw.h"
#include <string>

#define TEXT_DEFAULT_SPACING	2
#define	TEXT_DEFAULT_PADDING	5
#define TEXT_CHARS_PER_LINE		255
#define TEXT_WORD_LENGTH		50
#define TEXT_LINE_SEPERATOR		_T("|")

typedef std::basic_string<TCHAR>	tstring_t;

class Text
{
public:

	Text(CGapiDisplay* pDisplay);
	~Text();

	void				Draw(CGapiSurface* pBuffer, LONG x, LONG y) const;

	void				SetText(const tstring_t& text);
	const tstring_t&	GetText() const;

	void				SetRegion(DWORD width, DWORD height);
	const SIZE&			GetRegion() const;

	void				SetPadding(DWORD padding);
	DWORD				GetPadding() const;

	void				SetLineSpacing(DWORD spacing);
	DWORD				GetLineSpacing() const;

	// Use GapiDraw constants for value:
	//		GDDRAWTEXT_LEFT (default)
	//		GDDRAWTEXT_CENTER
	//		GDDRAWTEXT_RIGHT
	void				SetAlignment(DWORD alignment);
	DWORD				GetAlignment() const;

	void				SetFont(CGapiBitmapFont* pFont);

	// Formats the text to properly fit the specified region.
	// Always call this after the text, region, or font has
	// been altered, including during construction.
	void				Format();

private:

	void				RemoveLineSeperators();
	void				AlignText(DWORD numOfLines, DWORD fontHeight);

	CGapiBitmapFont*	GetDrawingFont() const;

	CGapiDisplay*		m_pDisplay;

	tstring_t			m_text;
	SIZE				m_region;

	DWORD				m_padding;
	DWORD				m_lineSpacing;

	DWORD				m_alignment;
	POINT				m_alignPos;

	CGapiBitmapFont*	m_pFont;
};

#endif	// __TEXT_H__